qulogic/pidgin

Parents 7d15ce7f8356
Children fe16c4d773b4
Rename PURPLE_PRESENCE_EXTENDED_AWAY to PURPLE_PRESENCE_DO_NOT_DISTURB

Testing Done:
Connected a demo protocol plugin and verified Ivanhoe's status said `Do not disturb`.

Reviewed at https://reviews.imfreedom.org/r/2833/
--- a/libpurple/protocols/demo/resources/contacts.json Sat Nov 18 02:49:16 2023 -0600
+++ b/libpurple/protocols/demo/resources/contacts.json Sun Nov 19 00:02:56 2023 -0600
@@ -72,7 +72,7 @@
"id": "markus"
},
"presence": {
- "primitive": "extended-away",
+ "primitive": "do-not-disturb",
"message": "Running all the things in valgrind..."
},
"tags": [
--- a/libpurple/purplepresence.c Sat Nov 18 02:49:16 2023 -0600
+++ b/libpurple/purplepresence.c Sun Nov 19 00:02:56 2023 -0600
@@ -816,7 +816,7 @@
case PURPLE_PRESENCE_PRIMITIVE_AWAY:
return _("Away");
break;
- case PURPLE_PRESENCE_PRIMITIVE_EXTENDED_AWAY:
+ case PURPLE_PRESENCE_PRIMITIVE_DO_NOT_DISTURB:
return _("Do not disturb");
break;
case PURPLE_PRESENCE_PRIMITIVE_STREAMING:
--- a/pidgin/pidginiconname.c Sat Nov 18 02:49:16 2023 -0600
+++ b/pidgin/pidginiconname.c Sun Nov 19 00:02:56 2023 -0600
@@ -46,7 +46,7 @@
return "pidgin-user-invisible";
break;
case PURPLE_STATUS_EXTENDED_AWAY:
- return "pidgin-user-extended-away";
+ return "pidgin-user-do-not-disturb";
break;
case PURPLE_STATUS_MOBILE:
case PURPLE_STATUS_UNSET:
@@ -107,8 +107,8 @@
case PURPLE_PRESENCE_PRIMITIVE_AWAY:
return "pidgin-user-away";
break;
- case PURPLE_PRESENCE_PRIMITIVE_EXTENDED_AWAY:
- return "pidgin-user-extended-away";
+ case PURPLE_PRESENCE_PRIMITIVE_DO_NOT_DISTURB:
+ return "pidgin-user-do-not-disturb";
break;
case PURPLE_PRESENCE_PRIMITIVE_STREAMING:
/* TODO: get an icon for streaming. */
Binary file pidgin/resources/icons/16x16/status/pidgin-user-do-not-disturb.png has changed
Binary file pidgin/resources/icons/16x16/status/pidgin-user-extended-away.png has changed
--- a/pidgin/resources/pidgin.gresource.xml Sat Nov 18 02:49:16 2023 -0600
+++ b/pidgin/resources/pidgin.gresource.xml Sun Nov 19 00:02:56 2023 -0600
@@ -51,7 +51,7 @@
<file>icons/16x16/status/pidgin-user-available.png</file>
<file>icons/16x16/status/pidgin-user-away.png</file>
<file>icons/16x16/status/pidgin-user-busy.png</file>
- <file>icons/16x16/status/pidgin-user-extended-away.png</file>
+ <file>icons/16x16/status/pidgin-user-do-not-disturb.png</file>
<file>icons/16x16/status/pidgin-user-invisible.png</file>
<file>icons/16x16/status/pidgin-user-offline.png</file>
<file>icons/16x16/status/pidgin-user-unavailable.png</file>
--- a/libpurple/purplepresence.h Sat Nov 18 02:49:16 2023 -0600
+++ b/libpurple/purplepresence.h Sun Nov 19 00:02:56 2023 -0600
@@ -66,10 +66,11 @@
* visible to others.
* @PURPLE_PRESENCE_PRIMITIVE_AWAY: The presence is online, but the user is
* away from their device.
* @PURPLE_PRESENCE_PRIMITIVE_EXTENDED_AWAY: Similar to
* @PURPLE_PRESENCE_PRIMITIVE_AWAY,
* but typically means the user does
* not want to be disturbed.
* @PURPLE_PRESENCE_PRIMITIVE_STREAMING: The presence is online but is
* streaming.
*
@@ -84,7 +85,7 @@
PURPLE_PRESENCE_PRIMITIVE_IDLE,
PURPLE_PRESENCE_PRIMITIVE_INVISIBLE,
PURPLE_PRESENCE_PRIMITIVE_AWAY,
- PURPLE_PRESENCE_PRIMITIVE_EXTENDED_AWAY,
+ PURPLE_PRESENCE_PRIMITIVE_DO_NOT_DISTURB,
PURPLE_PRESENCE_PRIMITIVE_STREAMING,
} PurplePresencePrimitive;
@@ -66,10 +66,11 @@
* @PURPLE_PRESENCE_PRIMITIVE_AWAY: The presence is online, but the user is
* away from their device.
- * @PURPLE_PRESENCE_PRIMITIVE_EXTENDED_AWAY: Similar to
- * @PURPLE_PRESENCE_PRIMITIVE_AWAY,
- * but typically means the user does
- * not want to be disturbed.
+ * @PURPLE_PRESENCE_PRIMITIVE_DO_NOT_DISTURB: Similar to
+ * @PURPLE_PRESENCE_PRIMITIVE_AWAY,
+ * but typically means the user has
+ * notifications and sounds
+ * disabled.
* @PURPLE_PRESENCE_PRIMITIVE_STREAMING: The presence is online but is
* streaming.